Learn R Programming

blockr.dock (version 0.1.0)

new_edit_board_extension: Edit board extension

Description

A simplistic example of an extension which can be used for manipulating the board via a table-based UI. Mainly relevant for testing purposes.

Usage

new_edit_board_extension(...)

Value

A board extension object that additionally inherits from edit_board_extension.

Arguments

...

Forwarded to new_dock_extension()

Examples

Run this code
ext <- new_edit_board_extension()
is_dock_extension(ext)

Run the code above in your browser using DataLab